@@ -3,6 +3,8 @@
 package KiokuDB::Backend::BDB::Manager;
 use Moose;
 
+use Path::Class;
+
 use Moose::Util::TypeConstraints;
 
 use namespace::clean -except => 'meta';
@@ -11,9 +13,21 @@ extends "BerkeleyDB::Manager";
 
 has '+home' => ( required => 1 );
 
-has '+data_dir' => ( default => "data" );
+sub BUILD {
+    my $self = shift;
 
-has '+log_dir' => ( default => "logs" );
+    my $home = dir($self->home);
+
+    # backwards compat
+    # this used to be the default, but makes using db_hotbackup hard
+    if ( -d $home->subdir("data") ) {
+        $self->meta->find_attribute_by_name("data_dir")->set_value($self, "data");
+    }
+
+    if ( -d $home->subdir("logs") ) {
+        $self->meta->find_attribute_by_name("log_dir")->set_value($self, "logs");
+    }
+}
 
 coerce( __PACKAGE__,
     from HashRef => via { __PACKAGE__->new(%$_) },
